;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "magit-tbdiff" "20250915.2109"
  "Magit extension for range diffs."
  '((emacs "26.1")
    (magit "4.0.0"))
  :url "https://github.com/magit/magit-tbdiff"
  :commit "f77cffb98dae726f011b133db8936df9ac4a657a"
  :revdesc "f77cffb98dae"
  :keywords '("vc" "tools")
  :authors '(("Kyle Meyer" . "kyle@kyleam.com"))
  :maintainers '(("Kyle Meyer" . "kyle@kyleam.com")))
